@@ -20,8 +20,6 @@ geocode_server <- function(url, token = arc_token()) {
   structure(res, class = c("GeocodeServer", "list"))
 }
 
-world_geocoder_url <- "https://geocode.arcgis.com/arcgis/rest/services/World/GeocodeServer"
-
 # Print method for the geocoder, must be exported
 #' @export
 print.GeocodeServer <- function(x, ...) {
@@ -47,9 +45,15 @@ print.GeocodeServer <- function(x, ...) {
 }
 
 # handy check function to see if the type is a GeocodeServer
-check_geocoder <- function(x, arg = rlang::caller_arg(x), call = rlang::caller_env()) {
+check_geocoder <- function(
+  x,
+  arg = rlang::caller_arg(x),
+  call = rlang::caller_env()
+) {
   if (!rlang::inherits_any(x, "GeocodeServer")) {
-    cli::cli_abort("Expected {.cls GeocodeServer}, {.arg {arg}} is {obj_type_friendly(x)}")
+    cli::cli_abort(
+      "Expected {.cls GeocodeServer}, {.arg {arg}} is {obj_type_friendly(x)}"
+    )
   }
 
   invisible(NULL)
@@ -68,9 +72,11 @@ capabilities <- function(geocoder) {
 #' @keywords internal
 #' @noRd
 has_custom_fields <- function(x) {
+  world <- world_geocoder()
+
   custom_fields <- setdiff(
     x$candidateFields$name,
-    arcgisgeocode::world_geocoder$candidateFields$name
+    world$candidateFields$name
   )
 
   length(custom_fields) > 0
